@@ -2,7 +2,6 @@ from datetime import datetime, timedelta
 import hashlib
 import logging
 import os
-from pickle import dumps as pickle
 
 from temboardagent.errors import UserError, HTTPError
 from temboardagent.postgres import Postgres
@@ -554,7 +553,6 @@ def schedule_operation(operation_type, conn, database,
         dt = datetime.strptime(datetimeutc, '%Y-%m-%dT%H:%M:%SZ')
 
         options = {
-            'config': pickle(app.config),
             'dbname': database,
         }
         if schema:
@@ -650,10 +648,10 @@ def list_scheduled_operation(app, operation_type, **kwargs):
 
         # We only want tasks for the operation type ('vacuum', 'analyze',
         # 'reindex')
-        if task['worker_name'] != operation_type + '_worker':
+        if task.worker_name != operation_type + '_worker':
             continue
 
-        options = task['options']
+        options = task.options
         # Filter by db/schema/table if provided
         if (all(k in kwargs for k in ['dbname', 'schema']) and
             (kwargs.get('dbname') != options.get('dbname') or
@@ -666,14 +664,14 @@ def list_scheduled_operation(app, operation_type, **kwargs):
             continue
 
         ret.append(dict(
-            id=task['id'],
+            id=task.id,
             dbname=options.get('dbname'),
             schema=options.get('schema'),
             table=options.get('table'),
             index=options.get('index'),
             mode=options.get('mode'),
-            datetime=task['start_datetime'].strftime("%Y-%m-%dT%H:%M:%SZ"),
-            status=task_status_label(task['status'])
+            datetime=task.start_datetime.strftime("%Y-%m-%dT%H:%M:%SZ"),
+            status=task_status_label(task.status)
         ))
     return ret
 
